@@ -20,6 +20,7 @@
 #include "lastactivewindow.h"
 
 // local
+#include "schemes.h"
 #include "trackedgeneralinfo.h"
 #include "windowstracker.h"
 #include "../abstractwindowinterface.h"
@@ -47,6 +48,12 @@ LastActiveWindow::LastActiveWindow(TrackedGeneralInfo *trackedInfo)
       m_windowsTracker(trackedInfo->wm()->windowsTracker()),
       m_wm(trackedInfo->wm())
 {
+    connect(m_wm->schemesTracker(), &Schemes::colorSchemeChanged, this, [&](WindowId wid) {
+        if (wid == m_winId) {
+            updateColorScheme();
+        }
+    });
+
     connect(m_windowsTracker, &Windows::windowChanged, this, &LastActiveWindow::windowChanged);
     connect(m_windowsTracker, &Windows::windowRemoved, this, &LastActiveWindow::windowRemoved);
 }
@@ -220,6 +227,21 @@ void LastActiveWindow::setAppName(QString appName)
     emit appNameChanged();
 }
 
+QString LastActiveWindow::colorScheme() const
+{
+    return m_colorScheme;
+}
+
+void LastActiveWindow::setColorScheme(QString scheme)
+{
+    if (m_colorScheme == scheme){
+        return;
+    }
+
+    m_colorScheme = scheme;
+    emit colorSchemeChanged();
+}
+
 QString LastActiveWindow::display() const
 {
     return m_display;
@@ -272,6 +294,12 @@ void LastActiveWindow::setWinId(QVariant winId)
 
 void LastActiveWindow::setInformation(const WindowInfoWrap &info)
 {
+    bool firstActiveness{false};
+
+    if (m_winId != info.wid()) {
+        firstActiveness = true;
+    }
+
     setWinId(info.wid());
 
     setIsValid(true);
@@ -285,6 +313,10 @@ void LastActiveWindow::setInformation(const WindowInfoWrap &info)
     setGeometry(info.geometry());
     setIsKeepAbove(info.isKeepAbove());
 
+    if (firstActiveness) {
+        updateColorScheme();
+    }
+
     if (info.appName().isEmpty()) {
         setAppName(m_windowsTracker->appNameFor(info.wid()));
     } else {
@@ -378,6 +410,14 @@ void LastActiveWindow::clearHistory()
     }
 }
 
+void LastActiveWindow::updateColorScheme()
+{
+    auto scheme = m_wm->schemesTracker()->schemeForWindow(m_winId);
+    if (scheme) {
+        setColorScheme(scheme->schemeFile());
+    }
+}
+
 
 //! FUNCTIONALITY
 void LastActiveWindow::requestActivate()
